# crystalpy

Python integration with crystal report for dynamic output

## Features

Connect crystal report with python 

## Installation

To install this project, run the following command:
```bash
pip install crystalpy-barno